@@ -1,13 +1,9 @@
 package Pod::Weaver::Section::GenerateSection;
-BEGIN {
-  $Pod::Weaver::Section::GenerateSection::AUTHORITY = 'cpan:CDRAUG';
-}
-{
-  $Pod::Weaver::Section::GenerateSection::VERSION = '1.01';
-}
+our $AUTHORITY = 'cpan:CDRAUG';
+$Pod::Weaver::Section::GenerateSection::VERSION = '1.02';
 use utf8;
 
-## Copyright (C) 2013 Carnë Draug <carandraug+dev@gmail.com>
+## Copyright (C) 2013-2016 Carnë Draug <carandraug+dev@gmail.com>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -25,7 +21,6 @@ use utf8;
 use strict;
 use warnings;
 use Moose;
-use Moose::Autobox;
 use MooseX::AttributeShortcuts;
 use MooseX::Types::Moose qw(ArrayRef Bool Int Str);
 with (
@@ -85,7 +80,7 @@ sub weave_section {
     return if $input->{zilla}->main_module->name ne $input->{filename};
   }
 
-  my $text = join ("\n", $self->text->flatten);
+  my $text = join ("\n", @{ $self->text });
   if ($self->is_template) {
     $text = $self->fill_in_string($text,
     {
@@ -110,16 +105,17 @@ sub weave_section {
       children => [$text],
     });
   }
-  $document->children->push($text);
+  push @{ $document->children }, $text;
 }
 
 __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -127,7 +123,7 @@ Pod::Weaver::Section::GenerateSection - add pod section from an interpolated pie
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -225,11 +221,10 @@ Carnë Draug <cdraug@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Carnë Draug.
+This software is Copyright (c) 2016 by Carnë Draug.
 
 This is free software, licensed under:
 
   The GNU General Public License, Version 3, June 2007
 
 =cut
-
